﻿using Microsoft.Win32;
using OOOWriteAndClear.DataBase;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Text.RegularExpressions;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace OOOWriteAndClear
{
    /// <summary>
    /// Логика взаимодействия для MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private List<Product> products = new List<Product>();

        private List<Product> productSortFiltrFind = new List<Product>();


        public MainWindow()
        {
            UploadItemsList();

            InitializeComponent();

            FiltringCB.SelectedIndex = 0;
            SortingCB.SelectedIndex = 0;
        }


        private void UploadItemsList()
        {
            using (VorobiewTradeEntities db = new VorobiewTradeEntities())
            {
                products = db.Product.Include("Manufacturer").ToList();
            }
        }

        private void SortFilterFind()
        {
            productSortFiltrFind = Sort(Searching(Filtring(products)));
            ItemsListView.ItemsSource = productSortFiltrFind;
        }

        private List<Product> Sort(List<Product> products)
        {
            switch (SortingCB.SelectedIndex)
            {
                case 0: return products.OrderBy(a => a.CostWithDiscount).ToList();
                case 1: return products.OrderByDescending(a => a.CostWithDiscount).ToList();
            }
            return products;
        }

        private List<Product> Filtring(List<Product> products)
        {
            switch (FiltringCB.SelectedIndex)
            {
                case 0: return products;
                case 1: return products.Where(a => a.ProductDiscountMax >= 0 && a.ProductDiscountMax < 10).ToList();
                case 2: return products.Where(a => a.ProductDiscountMax >= 10 && a.ProductDiscountMax < 15).ToList();
                case 3: return products.Where(a => a.ProductDiscountMax >= 15 && a.ProductDiscountMax < 101).ToList();
            }
            return products;
        }

        private List<Product> Searching(List<Product> products) => products.Where(a => Regex.IsMatch(a.ProductName, FindingTB.Text)).ToList();

        private void FiltringCB_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            SortFilterFind();
        }

        private void SortingCB_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            SortFilterFind();
        }

        private void FindingTB_TextChanged(object sender, TextChangedEventArgs e)
        {
            SortFilterFind();
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            PrintDialog printDialog = new PrintDialog();
            if(printDialog.ShowDialog() == true)
            {
                printDialog.PrintVisual(MainBorder, "Печать");
            }
        }

        private void MenuItem_Click(object sender, RoutedEventArgs e)
        {
            Product product = productSortFiltrFind[ItemsListView.SelectedIndex];
            if (Basket.order.OrderProduct.Where(a => a.Product == product).ToList().Count != 0)
                return;
            Basket.order.OrderProduct.Add(new OrderProduct() { Product = product, ProductAmount = 1 });
        }

        private void Button_Click_1(object sender, RoutedEventArgs e)
        {
            new Basket().ShowDialog();
        }
    }
}
